rnalysis.enrichment.EnrichmentProcessing.go\_enrichment
=======================================================

.. currentmodule:: rnalysis.enrichment

.. automethod:: EnrichmentProcessing.go_enrichment